@@ -8,13 +8,23 @@ class File():
         self.path = path
 
     def read(self, encoding: str = "utf-8", lines: bool = False):
+        """Reads file"""
         with open(self.path, "r", encoding=encoding) as f:
             return f.readlines() if lines else f.read()
 
     def create(self):
+        """Creates file if it doesn't exist"""
+        if self.exists(): return
+
         with open(self.path, "x"):
             return
 
+    def clean(self):
+        """Cleans file, if it exists - creates empty file"""
+
+        with open(self.path, "w") as f:
+            f.write("")
+
     def move(self, new_path: str):
         shutil.move(self.path, new_path)
 
