@@ -1,7 +1,5 @@
-import contextlib
-import os
-import sys
 import shutil
+import os
 
 
 class Folder():
@@ -10,8 +8,8 @@ class Folder():
         self.path = path
 
     def create(self):
-        with contextlib.suppress(FileExistsError):
-            os.mkdir(self.path)
+        if self.exists(): return
+        os.mkdir(self.path)
 
     def move(self, new_path: str):
         shutil.move(self.path, new_path)
@@ -20,4 +18,4 @@ class Folder():
         return os.path.isdir(self.path)
 
     def delete(self):
-        shutil.rmtree('/folder_name', ignore_errors=True)
\ No newline at end of file
+        shutil.rmtree(self.path, ignore_errors=True)
\ No newline at end of file
